﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Media;
using Infragistics.Controls.Charts;

namespace CustomTickersTest
{
    public class CustomTickmarkValues : TickmarkValues
    {
        #region Fields (3)

        protected double First;
        protected double Last;
        protected DoubleCollection Tickmarks;

        #endregion Fields


        #region Constructors (1)

        public CustomTickmarkValues(DoubleCollection doubleCollection)
        {
            // define custom tickmark values
            this.Tickmarks = doubleCollection;
        }

        #endregion Constructors


        #region Public Methods (3)

        #region Public (3)

        /// <summary>
        /// Initializes tickmark values prior to rendering axis labels, striplines, and gridlines
        /// </summary>
        /// <param name="initializationParameters"></param>
        public override void Initialize(TickmarkValuesInitializationParameters initializationParameters)
        {
            base.Initialize(initializationParameters);
            // Initialize is overridden in order to store the minimum and maximum values, 
            // which will be later used in the MajorValues() and MinorValues() methods.
            this.First = initializationParameters.VisibleMinimum;
            this.Last = initializationParameters.VisibleMaximum;
        }

        /// <summary>
        /// Returns values of major tickmarks
        /// </summary>
        /// <returns></returns>
        public override IEnumerable<double> MajorValues()
        {
            IEnumerable<double> values = Tickmarks.Where((value) => value >= this.First && value <= this.Last);
            return values;
        }

        /// <summary>
        /// Returns values of minor tickmarks
        /// </summary>
        /// <returns></returns>
        public override IEnumerable<double> MinorValues()
        {
            double start = this.First;
            for(double minorValue = start; minorValue < this.Last; minorValue += 1.0)
            {
                yield return minorValue;
            }
        }

        #endregion Public

        #endregion Public Methods
    }
}
